
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
    <script>
import extend from "@/extension/basic/materielInfo.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "物料信息",
      name: "materielInfo",
      url: "/MaterielInfo/",
      sortName: "id",
    });
    const editFormFields = ref({
      areaId: "",
      materielCode: "",
      materielName: "",
      materielDes: "",
      isMixBatch: "",
      isMixMateriel: "",
    });
    const editFormOptions = ref([
      [
        {
          title: "区域",
          required: true,
          field: "areaId",
          type: "string",
        },
        {
          title: "物料编号",
          required: true,
          field: "materielCode",
          type: "string",
        },
        {
          title: "物料名称",
          required: true,
          field: "materielName",
          type: "string",
        },
        {
          title: "计量单位",
          required: true,
          field: "unit",
          type: "string",
        },
      ],
      [
        {
          title: "允许混批",
          field: "isMixBatch",
          type: "string",
        },
        {
          title: "允许混料",
          field: "isMixMateriel",
          type: "string",
        },
        {
          title: "物料描述",
          field: "materielDes",
          type: "textarea",
        },
      ],
    ]);
    const searchFormFields = ref({
      materielCode: "",
      materielName: "",
      areaId: "",
    });
    const searchFormOptions = ref([
      [
        { title: "物料编号", field: "materielCode", type: "like" },
        { title: "物料名称", field: "materielName", type: "like" },
        { title: "设备状态", field: "deviceStatus" },
      ],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "areaId",
        title: "区域主键",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "materielCode",
        title: "物料编号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "materielName",
        title: "物料名称",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "materielDes",
        title: "物料描述",
        type: "decimal",
        width: 90,
        align: "left",
      },
      {
        field: "cotainerType",
        title: "容器类型",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "packspes",
        title: "包装规格",
        type: "int",
        width: 120,
        align: "left",
      },
      {
        field: "attribute",
        title: "物料属性",
        type: "string",
        width: 200,
        align: "left",
      },
      {
        field: "unit",
        title: "计量单位",
        type: "string",
        width: 180,
        align: "left",
      },
      {
        field: "validity",
        title: "有效期",
        type: "string",
        width: 120,
        align: "left",
      },
      {
        field: "safetyStock",
        title: "安全库存",
        type: "string",
        width: 120,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      table: "",
      columns: [],
      sortName: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
    